| Title: | Classify Domains using Webservices and Lists |
|---|---|
| Description: | Wraps various APIs and provides lists to classify domains. This includes... |
| Authors: | David Schoch [aut, cre] (ORCID: <https://orcid.org/0000-0003-2952-4812>) |
| Maintainer: | David Schoch <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-05 07:23:00 UTC |
| Source: | https://github.com/schochastics/domainator |
Domain list classification of domains into news,portals, search, and social media
domain_listdomain_list
An object of class data.frame with 663 rows and 2 columns.
Stier, S., Mangold, F., Scharkow, M., & Breuer, J. (2022). Post Post-Broadcast Democracy? News Exposure in the Age of Online Intermediaries. American Political Science Review, 116(2), 768-774.
Returns all of the possible categories from webshrinker.com that URLs, hostnames, and IP addresses can be associated with.
get_categories_shrinker(taxonomy = "iabv1")get_categories_shrinker(taxonomy = "iabv1")
taxonomy |
character. Which category taxonomy to use, either "iabv1" or "webshrinker" |
list of categories
## Not run: get_categories_shrinker(taxonomy = "iabv1") ## End(Not run)## Not run: get_categories_shrinker(taxonomy = "iabv1") ## End(Not run)
uses klazify.com to get the categories associated with the given URL.
get_url_category_klazify(url, raw = FALSE)get_url_category_klazify(url, raw = FALSE)
url |
character. URL to be categorized (needs https://www.) |
raw |
boolean. If TRUE returns the raw API response which contains more information than only the categories. |
data.frame with the inferred category and confidents score
## Not run: get_url_category_klazify("https://www.kicker.de") ## End(Not run)## Not run: get_url_category_klazify("https://www.kicker.de") ## End(Not run)
use linkpreview to get the description of a URL.
get_url_category_linkpreview(url)get_url_category_linkpreview(url)
url |
character. URL to be categorized |
data.frame with the title and description of a website
## Not run: get_url_category_linkpreview("https://www.google.com") ## End(Not run)## Not run: get_url_category_linkpreview("https://www.google.com") ## End(Not run)
uses webshrinker.com to get the categories associated with the given URL, hostname, or IP address
get_url_category_shrinker(url, taxonomy = "iabv1")get_url_category_shrinker(url, taxonomy = "iabv1")
url |
character. URL to be categorized (does not need https://www.) |
taxonomy |
character. Which category taxonomy to use, either "iabv1" or "webshrinker" |
data.frame with the inferred category and confidents score
## Not run: get_url_category_shrinker("kicker.de") ## End(Not run)## Not run: get_url_category_shrinker("kicker.de") ## End(Not run)
uses whoisxmlapi to get the categories associated with the given URL
get_url_category_whoisxml(url)get_url_category_whoisxml(url)
url |
character. URL to be categorized (doesnt need https://www.) |
data.frame with the inferred category and confidents score
## Not run: get_url_category_whoisxml("kicker.de") ## End(Not run)## Not run: get_url_category_whoisxml("kicker.de") ## End(Not run)
Classification of domains into different news types
news_typesnews_types
An object of class data.frame with 690 rows and 2 columns.
Stier, S., Mangold, F., Scharkow, M., & Breuer, J. (2022). Post Post-Broadcast Democracy? News Exposure in the Age of Online Intermediaries. American Political Science Review, 116(2), 768-774.
Domain list of online news
online_newsonline_news
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 542 rows and 2 columns.
Sebastian Stier, Nora Kirkizh, Caterina Froio, Ralph Schroeder. Populist attitudes and selective exposure to online news https://osf.io/5pe27
Domain list of us news contains a list of and information on 5,397 US news domains. The domains overwhelmingly represent US-based organizations, but since the list was partly sourced from browsing data, it also includes some international domains visited by US study participants.
us_newsus_news
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 5397 rows and 3 columns.
Clemm von Hohenberg, B., Menchen-Trevino, E., Casas, A., Wojcieszak, M. (2021). A list of over 5000 US news domains and their social media accounts. https://doi.org/10.5281/zenodo.7651047